import ListingCard from "./ListingCard";
import { Button } from "@/components/ui/button";

interface Listing {
  id: number;
  title: string;
  price: number | null;
  description: string;
  location: string;
  createdAt: string;
  isUrgent?: boolean;
  primaryImage?: string | null;
  userId: number;
}

interface ListingGridProps {
  listings: Listing[];
  title?: string;
  viewAllLink?: string;
  loading?: boolean;
  emptyMessage?: string;
  showLoadMore?: boolean;
  onLoadMore?: () => void;
  hasMore?: boolean;
}

const ListingGrid = ({
  listings,
  title,
  viewAllLink,
  loading = false,
  emptyMessage = "Aucune annonce trouvée",
  showLoadMore = false,
  onLoadMore,
  hasMore = false,
}: ListingGridProps) => {
  return (
    <section className="mb-10">
      {title && (
        <div className="flex justify-between items-center mb-6">
          <h2 className="text-2xl font-bold text-teal-800">{title}</h2>
          {viewAllLink && (
            <a href={viewAllLink} className="text-teal-600 hover:text-amber-500 hover:underline transition-colors">
              Voir toutes les annonces
            </a>
          )}
        </div>
      )}

      {loading ? (
        <div className="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-4 gap-6">
          {[...Array(4)].map((_, index) => (
            <div key={index} className="bg-teal-50 rounded-lg h-[280px] animate-pulse border border-teal-100"></div>
          ))}
        </div>
      ) : listings.length > 0 ? (
        <div className="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-4 gap-6">
          {listings.map((listing) => (
            <ListingCard key={listing.id} listing={listing} />
          ))}
        </div>
      ) : (
        <div className="text-center py-10 bg-teal-50 rounded-lg border border-teal-100">
          <p className="text-teal-600">{emptyMessage}</p>
        </div>
      )}

      {showLoadMore && listings.length > 0 && (
        <div className="mt-8 flex justify-center">
          <Button
            variant="outline"
            onClick={onLoadMore}
            disabled={!hasMore || loading}
            className="px-6 py-3 border-teal-300 text-teal-700 hover:bg-teal-50 hover:text-teal-800"
          >
            {loading ? "Chargement..." : "Voir plus d'annonces"}
          </Button>
        </div>
      )}
    </section>
  );
};

export default ListingGrid;
